#!/usr/local/bin/python -t
# $Id: import.py.in,v 1.3 2007/01/13 12:09:44 rockyb Exp $ -*- Python -*-
"Unit test of 'import pydb'"
import os, sys, unittest

top_builddir = "../"
if top_builddir[-1] != os.path.sep:
    top_builddir += os.path.sep
top_srcdir = ".."
if top_srcdir[-1] != os.path.sep:
    top_srcdir += os.path.sep

builddir     = "."
if builddir[-1] != os.path.sep:
    builddir += os.path.sep

srcdir = "."
if srcdir[-1] != os.path.sep:
    srcdir += os.path.sep

class PdbTests(unittest.TestCase):

    def test_import(self):
        """Test that 'import pydb' works"""
        cmd = ("/usr/local/bin/python -c 'import os, sys; " + 
        "sys.path.insert(0, \"%s\"); " +
        "sys.path.insert(0, \"%s\"); " +
        "import pydb'" ) % (top_srcdir, top_builddir)
        rc = os.system(cmd) >> 8
        self.assertEqual(0, rc, "python import pydb")
        return

if __name__ == "__main__":
    unittest.main()
